@@ -141,6 +141,7 @@ struct line *lp;
 		putchar('\n');
 
 	if (domake || expmake) {	/*  Get the shell to execute it  */
+		fflush(stdout);
 		if ((estat = dosh(q, shell)) != 0) {
 		    if (estat == -1)
 			fatal("Couldn't execute %s", shell,0);
@@ -380,16 +381,19 @@ struct name *np;
 {
 #ifdef unix
   struct stat info;
-  int         fd;
+  int r;
 
-
-  if (stat(np->n_name, &info) < 0) {
+  if (is_archive_ref(np->n_name)) {
+	r = archive_stat(np->n_name, &info);
+  } else {
+	r = stat(np->n_name, &info);
+  }
+  if (r < 0) {
 	if (errno != ENOENT)
 		fatal("Can't open %s; error %d", np->n_name, errno);
 
 	np->n_time = 0L;
-  }
-  else {
+  } else {
 	np->n_time = info.st_mtime;
 	np->n_flag |= N_EXISTS;
   }
@@ -691,7 +695,7 @@ char        **pinputname;
   else
      llp = np->n_line;
 
-  do {
+  while (llp) {
      for (dp = llp->l_dep; dp; dp = dp->d_next) {
         if( strncmp(*pbasename,dp->d_name->n_name,baselen) == 0) {
            *pinputname = dp->d_name->n_name;
@@ -702,10 +706,14 @@ char        **pinputname;
            dpflag = TRUE;
         }
      }
-  } while( !lp && (llp = llp->l_next));
+     if (lp) break;
+     llp = llp->l_next;
+  }
 
+#if NO_WE_DO_WANT_THIS_BASENAME
   free(*pbasename);  /* basename ambiguous or no dependency file */
   *pbasename = (char *)0;
+#endif
   return;
 }
 
