@@ -5,11 +5,6 @@
 #define _MINIX             1	/* tell headers to include MINIX stuff */
 #define _SYSTEM            1	/* tell headers that this is the kernel */
 
-/* The ANSI C namespace pollution rules forbid the use of sendrec etc. */
-#define send _send
-#define receive _receive
-#define sendrec _sendrec
-
 /* The following are so basic, all the *.c files get them automatically. */
 #include <minix/config.h>	/* MUST be first */
 #include <ansi.h>		/* MUST be second */
