@@ -5,18 +5,15 @@
 #define _MINIX             1	/* tell headers to include MINIX stuff */
 #define _SYSTEM            1	/* tell headers that this is the kernel */
 
-/* The ANSI C namespace pollution rules forbid the use of sendrec etc. */
-#define send _send
-#define receive _receive
-#define sendrec _sendrec
-
 /* The following are so basic, all the *.c files get them automatically. */
 #include <minix/config.h>	/* MUST be first */
 #include <ansi.h>		/* MUST be second */
 #include <sys/types.h>
 #include <minix/const.h>
 #include <minix/type.h>
+#include <minix/syslib.h>
 
+#include <string.h>
 #include <limits.h>
 #include <errno.h>
 
