@@ -3,7 +3,7 @@
   See the copyright notice in the ACK home directory, in the file "Copyright".
 */
 
-/* $Header: dvf4.c,v 1.4 89/07/25 14:19:18 ceriel Exp $ */
+/* $Header: dvf4.c,v 1.5 93/01/05 12:04:53 ceriel Exp $ */
 
 /*
 	DIVIDE TWO SINGLES - SINGLE Precision (dvf 4)
@@ -11,7 +11,7 @@
 
 #include	"FP_types.h"
 
-SINGLE
+void
 dvf4(s2,s1)
 SINGLE	s1,s2;
 {
@@ -23,5 +23,4 @@ SINGLE	s1,s2;
 		/* do a divide */
 	div_ext(&e1,&e2);
 	compact(&e1,&s1,sizeof(SINGLE));
-	return s1;
 }
