@@ -364,10 +364,12 @@ void test21e()
   errno = 0;
   if (mkdir("D1", 0777) != -1) e(8);
   if (errno != EEXIST) e(9);
+#if NAME_MAX == 14
   if (mkdir("D1/ABCDEFGHIJKLMNOPQRSTUVWXYZ", 0777) != 0) e(10);
   if (access("D1/ABCDEFGHIJKLMN", 7 ) != 0) e(11);
   if (rmdir("D1/ABCDEFGHIJKLMNOPQ") != 0) e(12);
   if (access("D1/ABCDEFGHIJKLMN", 7 ) != -1) e(13);
+#endif
   errno = 0;
   if (mkdir("D1/D2/x", 0777) != -1) e(14);
   if (errno != ENOENT) e(15);
@@ -625,7 +627,6 @@ void test21n()
 
 void test21o()
 {
-
   /* Test trying to remove . and .. */
   subtest = 14;
   if (mkdir("D1", 0777) != 0) e(1);
@@ -677,7 +678,6 @@ int n;
 
 void quit()
 {
-
   chdir("..");
   system("rm -rf DIR*");
 
